###################################################
#
# HMS NixOS Conf
# 2020-8-29
#

{ config, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
      # home-manager config
      #./home.nix
    ];
    
    #### Boot
    boot.loader.grub.enable = true;
    boot.loader.grub.version = 2;
    boot.loader.grub.device = "/dev/sda"; # or "nodev" for efi only

    #### Network
    networking.useDHCP = false;
    networking.interfaces.ens18.useDHCP = true;

    #### Time/Date
    time.timeZone = "America/Los_Angeles";

    #### Packages
    nixpkgs.config = {
        allowUnfree = true;
    };
    environment.systemPackages = with pkgs; [
        # Basics
        git
        wget
        youtube-dl
        tmux
        neofetch
        sakura
        firefox
        home-manager
        # xdg
        xdg-user-dirs
        xdg_utils
        # Editors
        vscode
        nano
        vim
        # Social
        discord
        signal-desktop
        # Design
        darktable
        inkscape
        gimp
        # Torrents
        transmission
        # Other
        simplenote
        # Auth
        yubioath-desktop
    ];

    #### Services
    services.sshd.enable = true;

    #### xserver
    services.xserver.enable = true;
    services.xserver.layout = "us";
    # Display Manager
    services.xserver.displayManager.lightdm.enable = true;
    services.xserver.displayManager.defaultSession = "none+awesome";
    services.xserver.displayManager.lightdm.greeters.mini = {
        enable = true;
        user = "hms";
        extraConfig = ''
            [greeter]
            show-password-label = true
            password-label-text = Enter Credentials:
            invalid-password-text = Credentials Invalid
            show-input-cursor = true
            password-alignment = right
            show-image-on-all-monitors = false
            [greeter-theme]
            background-image = ""
            font = "Sans"
            font-size = 1em
            font-weight = bold
            font-style = normal
            text-color = "#080800"
            error-color = "#F8F8F0"
            background-color = "#1B1D1E"
            window-color = "#F92672"
            border-color = "#080800"
            border-width = 2px
            layout-space = 15
            password-color = "#F8F8F0"
            password-background-color = "#1B1D1E"
            password-border-color = "#080800"
            password-border-width = 2px
        '';
    };
    # Desktop Manager
    #services.xserver.desktopManager.mate.enable = true;
    # Window Manager
    services.xserver.windowManager.awesome.enable = true;

    #### User
    users.users.hms = {
    isNormalUser = true;
    home = "/home/hms";
    extraGroups = [ "wheel" ]; # Enable ‘sudo’ for the user.
    };

    # This value determines the NixOS release from which the default
    # settings for stateful data, like file locations and database versions
    # on your system were taken. It‘s perfectly fine and recommended to leave
    # this value at the release version of the first install of this system.
    # Before changing this value read the documentation for this option
    # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
    system.stateVersion = "20.03"; # Did you read the comment?

}
  